@@ -70,7 +70,6 @@ impl Session {
                             warn!("Processing error received. {:?}", error);
                             // TODO: Handle lazy message errors
                         }
-                        msg => warn!("SupportingInfo received: {:?}", msg),
                     }
                 }
                 msg_type => {
@@ -218,14 +217,6 @@ impl Session {
                         trace!("No channel found for {:?}", correlation_id);
                     }
                 }
-                ProcessMsg::Event {
-                    event,
-                    correlation_id,
-                    ..
-                } => {
-                    debug!("Event received to be processed: {:?}", correlation_id);
-                    trace!("Event received is: {:?}", event);
-                }
                 ProcessMsg::CmdError {
                     error,
                     correlation_id,
