@@ -21,17 +21,19 @@
 //!
 //! Setting up a random client for read only access:
 //!
-/// # Examples
-///
-/// TODO: update once data types are crdt compliant
-///
+//! # Examples
+//!
+//! TODO: update once data types are crdt compliant
+//!
+
 mod connections;
 mod errors;
 
 // Export public API.
 
 pub use client_api::Client;
-pub use errors::{Error, ErrorMessage};
+pub use errors::Error;
+pub use errors::ErrorMessage;
 pub use qp2p::Config as QuicP2pConfig;
 
 /// Client trait and related constants.
