@@ -16,7 +16,7 @@ mod sequence_storage;
 use crate::dbs::UsedSpace;
 use crate::messaging::{
     data::{CmdError, DataCmd, DataExchange, DataMsg, DataQuery, ProcessMsg, QueryResponse},
-    ClientSigned, DstLocation, EndUser, MessageId,
+    ClientAuthority, ClientSigned, DstLocation, EndUser, MessageId, WireMsg,
 };
 use crate::node::{
     capacity::Capacity,
@@ -96,12 +96,10 @@ impl Metadata {
         &mut self,
         cmd: DataCmd,
         id: MessageId,
-        client_signed: ClientSigned,
+        client_auth: ClientAuthority,
         origin: EndUser,
     ) -> Result<NodeDuty> {
-        self.elder_stores
-            .write(cmd, id, client_signed, origin)
-            .await
+        self.elder_stores.write(cmd, id, client_auth, origin).await
     }
 
     /// Adds a given node to the list of full nodes.
@@ -162,3 +160,10 @@ fn build_client_error_response(error: CmdError, msg_id: MessageId, origin: EndUs
         aggregation: false,
     }
 }
+
+// TODO: verify earlier so that this isn't needed
+fn verify_op(client_signed: ClientSigned, cmd: DataCmd) -> Result<ClientAuthority> {
+    let message = DataMsg::Process(ProcessMsg::Cmd(cmd));
+    let payload = WireMsg::serialize_msg_payload(&message)?;
+    Ok(client_signed.verify(&payload)?)
+}
