@@ -17,7 +17,6 @@ pub mod utils;
 mod chunk;
 mod errors;
 mod keys;
-mod map;
 mod section;
 mod sequence;
 mod token;
@@ -34,11 +33,6 @@ pub use keys::{
     secret_key::SecretKey,
     signature::{Signature, SignatureShare},
 };
-pub use map::{
-    Action as MapAction, Address as MapAddress, Entries as MapEntries,
-    EntryAction as MapEntryAction, EntryActions as MapEntryActions, Kind as MapKind, Map,
-    PermissionSet as MapPermissionSet, Value as MapValue, Values as MapValues,
-};
 pub use register::Address as RegisterAddress;
 pub use section::SectionElders;
 pub use sequence::{
@@ -64,8 +58,6 @@ use xor_name::XorName;
 pub enum Data {
     /// Chunk.
     Chunk(Chunk),
-    /// Map.
-    Map(Map),
     /// Sequence.
     Sequence(Sequence),
     /// Register.
@@ -77,8 +69,6 @@ pub enum Data {
 pub enum DataAddress {
     /// Chunk Address
     Chunk(ChunkAddress),
-    /// Map Address
-    Map(MapAddress),
     /// Sequence Address
     Sequence(SequenceAddress),
     /// Register Address
@@ -90,7 +80,6 @@ impl Data {
     pub fn is_public(&self) -> bool {
         match *self {
             Self::Chunk(ref chunk) => chunk.is_public(),
-            Self::Map(_) => false,
             Self::Sequence(ref sequence) => sequence.is_public(),
             Self::Register(ref register) => register.is_public(),
         }
@@ -108,12 +97,6 @@ impl From<Chunk> for Data {
     }
 }
 
-impl From<Map> for Data {
-    fn from(data: Map) -> Self {
-        Self::Map(data)
-    }
-}
-
 impl From<Sequence> for Data {
     fn from(data: Sequence) -> Self {
         Self::Sequence(data)
